@@ -1,7 +1,7 @@
 import numpy as np
 #!/usr/bin/env python3
 '''
-Implementation arXiv:1905.13729:
+Implementation of arXiv:1905.13729:
 
 A set of $N$  $n_\alpha$ integers that satisfy Diophantine 
 equations
@@ -44,7 +44,7 @@ class cfree(object):
     * `simplified`: solution with gcd=1 
     '''
     def __call__(self,l,k,sort=True,reverse=False):
-        zz=_z(l,k,sort=True,reverse=False)
+        zz=_z(l,k,sort=sort,reverse=reverse)
         self.gcd=np.gcd.reduce(zz)
         self.simplified=(zz/self.gcd).astype(int)
         return zz
